@@ -37,7 +37,9 @@ apply_pr_options = github_options + deployment_options + [
                  is_flag=True, default=False),
     click.option("--prs", help="Pull request to apply", default=''),
     click.option("--reject", help="Use reject to deploy diff", is_flag=True, default=False),
-    click.option("--skip-rolling-check", help="Allow to skip rolling branch check", is_flag=True, default=False)
+    click.option("--skip-rolling-check", help="Allow to skip rolling branch check", is_flag=True, default=False),
+    click.option("--exit-code-failure", help="If enabled, process will terminate with exit 1 if had some error", is_flag=True, default=False),
+    click.option("--no-set-label", help="Don't set deployed label on PR", is_flag=True, default=False)
 ]
 
 status_options = github_options + [
@@ -108,7 +110,7 @@ def apply_pr(
     pr, host, from_number=0, from_commit=None, force_hostname=False,
     owner='gisce', repository='erp', src='/home/erp/src', sudo_user='erp',
     auto_exit=True, force_name=None, re_deploy=False, as_diff=False, prs='',
-    environ='pre', reject=False, skip_rolling_check=False
+    environ='pre', reject=False, skip_rolling_check=False, exit_code_failure=False, no_set_label=False
 ):
     """
     Deploy a PR into a remote server via Fabric
@@ -169,7 +171,8 @@ def apply_pr(
             src=src, owner=owner, repository=repository, sudo_user=sudo_user,
             host='{}:{}'.format(url.hostname, (url.port or 22)), auto_exit=auto_exit,
             force_name=force_name, re_deploy=re_deploy, as_diff=as_diff,
-            environment=environ, reject=reject, skip_rolling_check=skip_rolling_check
+            environment=environ, reject=reject, skip_rolling_check=skip_rolling_check,
+            no_set_label=no_set_label
         )
         result_list = list(result.items())
         if not result_list[0][1]:
@@ -179,6 +182,8 @@ def apply_pr(
         click.echo(colors.red(
             u"Failed PRS :{}".format(' '.join(failed_prs))
         ))
+        if exit_code_failure:
+            sys.exit(1)
     return results
 
 
